(window.webpackJsonp=window.webpackJsonp||[]).push([["start"],{cd28:function(t,e,r){"use strict";r.r(e);var n=r("a34a"),o=r.n(n),c=r("9ab4"),u=r("0613"),a=r("d568"),i=r("2963"),f=r("60a3");function _typeof(t){return(_typeof="function"==typeof Symbol&&"symbol"==typeof Symbol.iterator?function _typeof(t){return typeof t}:function _typeof(t){return t&&"function"==typeof Symbol&&t.constructor===Symbol&&t!==Symbol.prototype?"symbol":typeof t})(t)}function _classCallCheck(t,e){if(!(t instanceof e))throw new TypeError("Cannot call a class as a function")}function _defineProperties(t,e){for(var r=0;r<e.length;r++){var n=e[r];n.enumerable=n.enumerable||!1,n.configurable=!0,"value"in n&&(n.writable=!0),Object.defineProperty(t,n.key,n)}}function _setPrototypeOf(t,e){return(_setPrototypeOf=Object.setPrototypeOf||function _setPrototypeOf(t,e){return t.__proto__=e,t})(t,e)}function _createSuper(t){var e=function _isNativeReflectConstruct(){if("undefined"==typeof Reflect||!Reflect.construct)return!1;if(Reflect.construct.sham)return!1;if("function"==typeof Proxy)return!0;try{return Boolean.prototype.valueOf.call(Reflect.construct(Boolean,[],(function(){}))),!0}catch(t){return!1}}();return function _createSuperInternal(){var r,n=_getPrototypeOf(t);if(e){var o=_getPrototypeOf(this).constructor;r=Reflect.construct(n,arguments,o)}else r=n.apply(this,arguments);return _possibleConstructorReturn(this,r)}}function _possibleConstructorReturn(t,e){return!e||"object"!==_typeof(e)&&"function"!=typeof e?function _assertThisInitialized(t){if(void 0===t)throw new ReferenceError("this hasn't been initialised - super() hasn't been called");return t}(t):e}function _getPrototypeOf(t){return(_getPrototypeOf=Object.setPrototypeOf?Object.getPrototypeOf:function _getPrototypeOf(t){return t.__proto__||Object.getPrototypeOf(t)})(t)}function asyncGeneratorStep(t,e,r,n,o,c,u){try{var a=t[c](u),i=a.value}catch(t){return void r(t)}a.done?e(i):Promise.resolve(i).then(n,o)}var s=function(){var t=function _asyncToGenerator(t){return function(){var e=this,r=arguments;return new Promise((function(n,o){var c=t.apply(e,r);function _next(t){asyncGeneratorStep(c,n,o,_next,_throw,"next",t)}function _throw(t){asyncGeneratorStep(c,n,o,_next,_throw,"throw",t)}_next(void 0)}))}}(o.a.mark((function _callee(t,e,r){return o.a.wrap((function _callee$(e){for(;;)switch(e.prev=e.next){case 0:return e.next=2,Object(a.c)(u.b);case 2:Object(i.e)(u.b)?"/login"===t.path||"/"===t.path?r("/main"):r():!1===Object(i.e)(u.b)&&("/"===t.path||t.path.startsWith("/main")?r({path:"/login"}):r());case 3:case"end":return e.stop()}}),_callee)})));return function startRouteGuard(e,r,n){return t.apply(this,arguments)}}(),p=function(t){!function _inherits(t,e){if("function"!=typeof e&&null!==e)throw new TypeError("Super expression must either be null or a function");t.prototype=Object.create(e&&e.prototype,{constructor:{value:t,writable:!0,configurable:!0}}),e&&_setPrototypeOf(t,e)}(Start,t);var e=_createSuper(Start);function Start(){return _classCallCheck(this,Start),e.apply(this,arguments)}return function _createClass(t,e,r){return e&&_defineProperties(t.prototype,e),r&&_defineProperties(t,r),t}(Start,[{key:"beforeRouteEnter",value:function beforeRouteEnter(t,e,r){s(t,e,r)}},{key:"beforeRouteUpdate",value:function beforeRouteUpdate(t,e,r){s(t,e,r)}}]),Start}(f.c),l=p=Object(c.a)([f.a],p),y=r("2877"),_=Object(y.a)(l,(function(){var t=this.$createElement;return(this._self._c||t)("router-view")}),[],!1,null,null,null);e.default=_.exports}}]);
//# sourceMappingURL=start.76ff2574.js.map